@@ -72,6 +72,12 @@ static gboolean ev_metadata_manager_save (gpointer data);
 
 static EvMetadataManager *ev_metadata_manager = NULL;
 
+/**
+ * item_free:
+ * @data: a pointer to a #Item data
+ *
+ * It does free the values on the #GHashTable where data points.
+ */
 static void
 item_free (gpointer data)
 {
@@ -87,17 +93,16 @@ item_free (gpointer data)
 	g_free (item);
 }
 
-void ev_metadata_arm_timeout(void)
-{
-	if (ev_metadata_manager->timeout_id)
-		return;
-	ev_metadata_manager->timeout_id = 
-		g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE,
-				    2000, /* 2 sec */
-				    (GSourceFunc)ev_metadata_manager_save,
-				    NULL,
-				    NULL);
-}
+/**
+ * ev_metadata_manager_init:
+ *
+ * Creates an EvMetadataManager with default values.
+ *
+ *  values_loaded   ->  %FALSE.
+ *  modified        ->  %FALSE.
+ *  timeout_id      ->  the id of the event source.
+ *  items           ->  a new full empty #GHashTable.
+ */
 void
 ev_metadata_manager_init (void)
 {
@@ -112,6 +117,12 @@ ev_metadata_manager_init (void)
 				       g_free,
 				       item_free);
 
+	ev_metadata_manager->timeout_id = 
+		g_timeout_add_full (G_PRIORITY_DEFAULT_IDLE,
+				    2000, /* 2 sec */
+				    (GSourceFunc)ev_metadata_manager_save,
+				    NULL,
+				    NULL);
 }
 
 /* This function must be called before exiting ev */
@@ -121,8 +132,7 @@ ev_metadata_manager_shutdown (void)
 	if (ev_metadata_manager == NULL)
 		return;
 
-	if (ev_metadata_manager->timeout_id)
-		g_source_remove (ev_metadata_manager->timeout_id);
+	g_source_remove (ev_metadata_manager->timeout_id);
 
 	ev_metadata_manager_save (NULL);
 
@@ -382,12 +392,11 @@ ev_metadata_manager_set_last (const gchar *key,
 
 	item->atime = time (NULL);
 	ev_metadata_manager->modified = TRUE;
-	ev_metadata_arm_timeout();
 	return;
 }
 				 
 /**
- * ev_metadata_manager_set:
+ * ev_metadata_manager_get:
  * @uri: Uri to set data for, if @NULL, we return default value
  * @key: Key to set uri
  * @value: GValue struct filled up with value
@@ -518,7 +527,6 @@ ev_metadata_manager_set (const gchar  *uri,
 	item->atime = time (NULL);
 
 	ev_metadata_manager->modified = TRUE;
-	ev_metadata_arm_timeout();
 }
 
 static void
@@ -639,10 +647,8 @@ ev_metadata_manager_save (gpointer data)
 	xmlNodePtr root;
 	gchar *file_name;
 
-	ev_metadata_manager->timeout_id = 0;
-
 	if (!ev_metadata_manager->modified)
-		return FALSE;
+		return TRUE;
 
 	resize_items ();
 		
@@ -668,7 +674,7 @@ ev_metadata_manager_save (gpointer data)
 
 	ev_metadata_manager->modified = FALSE;
 
-	return FALSE;
+	return TRUE;
 }
 
 void
